Identify areas of activation for each field from the result of BayesGLM
or fit_bayesglm.
activations(
x,
Bayes = TRUE,
gamma = NULL,
alpha = 0.05,
correction = c("FWER", "FDR", "none"),
fields = NULL,
sessions = NULL,
verbose = 1
)id_activations(
x,
Bayes = TRUE,
gamma = NULL,
alpha = 0.05,
correction = c("FWER", "FDR", "none"),
fields = NULL,
sessions = NULL,
verbose = 1
)
An "act_BGLM" or "act_fit_bglm" object, a
list which indicates the activated locations along with related information.
Result of BayesGLM or fit_bayesglm model
call, of class "BGLM" or "fit_bglm".
Use spatial Bayesian modeling to identify activations based on
the joint posterior distribution? Default: TRUE. If FALSE,
activations will be based on classical (massive univariate) GLM model, with
multiple comparisons correction (see correction). Note that TRUE
is only applicable if x includes Bayesian results (i.e.
x <- BayesGLM(..., Bayes = TRUE) was run.)
Activation threshold, for example 1 for 1 percent
signal change if scale_BOLD=="mean" during model estimation. Setting
a gamma is required for the Bayesian method; NULL
(default) will use a gamma of zero for the classical method.
Significance level for inference. Default: 0.05.
For the classical method only: Type of multiple comparisons
correction: "FWER" (Bonferroni correction, the default), "FDR"
(Benjamini Hochberg), or "none".
The field(s) to identify activations for. Give either the name(s)
as a character vector, or the numerical indices. If NULL (default),
analyze all fields.
The session(s) to identify activations for. Give either the
name(s) as a character vector, or the numerical indices. If NULL
(default), analyze the first session.
1 (default) to print occasional updates during model
computation; 2 for occasional updates as well as running INLA in
verbose mode (if Bayes), or 0 for no printed updates.