Identification of areas of activation in a General Linear Model using classical methods
activations.classical(
x,
gamma = 0,
alpha = 0.05,
correction = c("FWER", "FDR", "none"),
fields,
session,
mesh = NULL
)A matrix corresponding to the 0-1 activation status for the model coefficients.
A BayesGLM object
See activations.
(Optional) An "inla.mesh" object (see make_mesh for
surface data). Only necessary for computing surface areas of identified activations.