Identifies areas of activation given an activation threshold and significance level using joint posterior probabilities
activations.posterior(x, fields, session, alpha = 0.05, gamma)A list with two elements: active, which gives a matrix of zeros
and ones of the same dimension as x$field_estimates${session},
and excur_result, an object of class "excurobj" (see INLA's excursions.inla for
more information).
Result of BayesGLM, of class "BGLM".
See activations.
For a given latent field, identifies locations that exceed a certain activation threshold (e.g. 1 percent signal change) at a given significance level, based on the joint posterior distribution of the latent field.