combine_sessions
If multiple sessions are provided, should their data be combined and analyzed as a single session?
If TRUE (default), the multiple sessions will be concatenated along
time after scaling and nuisance regression, but before prewhitening. If
FALSE, each session will be analyzed separately, except that a single
estimate of the AR model coefficients for prewhitening is used, estimated
across all sessions.