Identify areas of activation for each task from the result of BayesGLM
or BayesGLM_cifti.
id_activations(
model_obj,
tasks = NULL,
sessions = NULL,
method = c("Bayesian", "classical"),
alpha = 0.05,
gamma = NULL,
correction = c("FWER", "FDR", "none"),
verbose = 1
)An "act_BayesGLM" or "act_BayesGLM_cifti" object, a
list which indicates the activated locations along with related information.
Result of BayesGLM or BayesGLM_cifti model
call, of class "BayesGLM" or "BayesGLM_cifti".
The task(s) to identify activations for. Give either the name(s)
as a character vector, or the numerical indices. If NULL (default),
analyze all tasks.
The session(s) to identify activations for. Give either the
name(s) as a character vector, or the numerical indices. If NULL
(default), analyze the first session.
Currently, if multiple sessions are provided, activations are identified separately for each session. (Information is not combined between the different sessions.)
"Bayesian" (default) or "classical". If
model_obj does not have Bayesian results because Bayes was set
to FALSE, only the "classical" method can be used.
Significance level. Default: 0.05.
Activation threshold, for example 1 for 1\
change if scale_BOLD=="mean" during model estimation. Setting a
gamma is required for the Bayesian method; NULL (default)
will use a gamma of zero for the classical method.
For the classical method only: Type of multiple comparisons
correction: "FWER" (Bonferroni correction, the default), "FDR"
(Benjamini Hochberg), or "none".
Should updates be printed? Use 1 (default) for
occasional updates, 2 for occasional updates as well as running INLA
in verbose mode (if applicable), or 0 for no updates.