Identification of areas of activation in a General Linear Model using classical methods
id_activations.classical(
model_obj,
tasks,
session,
alpha = 0.05,
gamma = 0,
correction = c("FWER", "FDR", "none"),
mesh = NULL
)A matrix corresponding to the 0-1 activation status for the model coefficients.
A BayesGLM object
See id_activations.
(character) Either 'FWER' or 'FDR'. 'FWER' corresponds to the family-wise error rate with Bonferroni correction, and 'FDR' refers to the false discovery rate using Benjamini-Hochberg.
(Optional) An "inla.mesh" object (see make_mesh for
surface data). Only necessary for computing surface areas of identified activations.