Activations prevalence.
prevalence(
act_list,
gamma_idx = 1,
p_test = NULL,
alpha = 0.05,
correction = c("FWER", "FDR", "none")
)A list containing the prevalences of activation, as a proportion of
the results from act_list.
List of activations from activations. All
should have the same sessions, fields, and brainstructures.
If activations at multiple thresholds were computed, which threshold should be used for prevalence? Default: the first (lowest).
For inference: the expected baseline rate of activation for all
data locations, under the null hypothesis. Default: NULL (do not
perform hypothesis testing).
Significance level for inference. Default: .05.
For the classical method only: Type of multiple comparisons
correction: "FWER" (Bonferroni correction, the default), "FDR"
(Benjamini Hochberg), or "none".