Transforms the usual TxV BOLD data matrix Y into vector form, and the usual TxK design matrix X into big sparse matrix form for use in Bayesian GLM.
sparse_and_PW(
BOLD,
design,
spatial,
spde,
field_names,
design_type,
valid_cols,
nT,
sqrtInv_all
)A list containing fields y and A (see Details)
See fit_bayesglm.
See fit_bayesglm.
See fit_bayesglm.
The Bayesian GLM requires y (a vector of length TV containing the BOLD data)
and X_k (a sparse TVxV matrix corresponding to the kth field regressor) for each field k.
The design matrices are combined as A=cbind(X_1,...,X_K).
The Bayesian GLM requires y (a vector of length TV containing the BOLD data)
and X_k (a sparse TVxV matrix corresponding to the kth field regressor) for each field k.
The design matrices are combined as A=cbind(X_1,...,X_K).