maskMdat is a subset of maskIn. x is masked by
maskMdat; this function makes it masked by maskIn instead
and uses fill_val for the previously masked-out locations.
unmask_Mdat2In(x, maskIn, maskMdat, fill_val = NA)The matrix to unmask
The input mask, and the modeled locations mask, as logical vectors. The latter should be a subset of the former. They should have the same length.
The fill value. Default: NA.